@@ -6,7 +6,7 @@ use Mojo::UserAgent;
 use Mojo::Promise;
 use Mojo::IOLoop;
 
-our $VERSION = '0.27';
+our $VERSION = '0.28';
 
 # Todo:
 # - Better test tracking API support
@@ -42,6 +42,7 @@ sub register {
   # No script route defined
   my $script_route = 0;
 
+  my $append = '' . ($plugin_param->{append} || '');
 
   # Create Mojo::UserAgent
   $plugin->ua(
@@ -110,8 +111,8 @@ sub register {
           return '';
         };
 
-        return b("<script src=\"$prot://${url}piwik.js\" async defer></script>" .
-                   '<script src="' . $c->url_for('piwik_track_script')->to_abs . '"></script>');
+        return b('<script src="' . $c->url_for('piwik_track_script')->to_abs . '"></script>' .
+                   "<script src=\"$prot://${url}piwik.js\" async defer></script>");
       }
 
       # Render opt-out tag
@@ -142,16 +143,14 @@ sub register {
 
       # Create piwik tag
       b(<<"SCRIPTTAG");
-<script type="text/javascript">var _paq=_paq||[];(function(){var
-u='http'+((document.location.protocol=='https:')?'s':'')+'://$url';
-with(_paq){push(['setSiteId',$site_id]);push(['setTrackerUrl',u+'piwik.php']);
-push(['trackPageView'])};var
-d=document,g=d.createElement('script'),s=d.getElementsByTagName('script')[0];
-if(!s){s=d.getElementsByTagName('head')[0].firstChild};
-with(g){type='text/javascript';defer=async=true;
-src=u+'piwik.js';s.parentNode.insertBefore(g,s)}})();</script>
-<noscript><img src="${prot}://${url}piwik.php?idSite=${site_id}&amp;rec=1" alt=""
-style="border:0" /></noscript>
+<script type="text/javascript">var _paq=window._paq=window._paq||[];
+_paq.push(['trackPageView']);_paq.push(['enableLinkTracking']);
+(function(){var u='http'+((document.location.protocol=='https:')?'s':'')+'://$url';
+_paq.push(['setTrackerUrl',u+'piwik.php']);_paq.push(['setSiteId',${site_id}]);
+var d=document,g=d.createElement('script'),s=d.getElementsByTagName('script')[0];
+g.type='text/javascript';g.async=true; g.src=u+'piwik.js'; s.parentNode.insertBefore(g,s);
+})();$append</script>
+<noscript><img src="${prot}://${url}piwik.php?idSite=${site_id}&amp;rec=1" alt="" style="border:0"/></noscript>
 SCRIPTTAG
     });
 
@@ -189,11 +188,12 @@ SCRIPTTAG
             # Render tracking code
             return $c->render(
               format => 'js',
-              text => 'var _paq=window._paq||[];' .
+              text => 'var _paq=window._paq=window._paq||[];' .
                 "_paq.push(['setTrackerUrl','$prot://${url}piwik.php']);" .
                 "_paq.push(['setSiteId',$site_id]);" .
                 q!_paq.push(['trackPageView']);! .
-                q!_paq.push(['enableLinkTracking']);!
+                q!_paq.push(['enableLinkTracking']);! .
+                $append
               );
           }
         )->name('piwik_track_script');
@@ -599,6 +599,12 @@ from stash as C<piwik.embed>.
 C<token_auth> - Token for authentication.
 Used only for the Piwik API.
 
+=item
+
+C<append> - Additional tracking code, that is appended to the code
+generated by L</piwik_tag> and the C<track_script> of the piwik shortcut.
+B<Experimental!>
+
 =back
 
 All parameters can be set either as part of the configuration
@@ -857,14 +863,14 @@ L<Mojolicious>.
 Please make sure you are using Matomo (Piwik) in compliance to the law.
 For german users,
 L<this information|https://www.datenschutzzentrum.de/uploads/projekte/verbraucherdatenschutz/20110315-webanalyse-piwik.pdf>
-(last accessed on 2019-12-06)
+(last accessed on 2021-01-19)
 may help you to design your service correctly.
 You may need to inform your users about your usage of
 Piwik, especially if you are located in the European Union.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2012-2019, L<Nils Diewald|https://nils-diewald.de/>.
+Copyright (C) 2012-2021, L<Nils Diewald|https://nils-diewald.de/>.
 
 This program is free software, you can redistribute it and/or
 modify it under the terms of the Artistic License version 2.0.
